FILE_EXTENSIONS = {  'Adobe Flash':'swf',
					 'Adobe Portable Document Format':'pdf',
					 'Adobe PostScript':'ps',
					 'Autodesk Design Web Format': 'dwf',
					 'Google Earth': 'kml',
					 'XML': 'xml',
					 'Microsoft PowerPoint': 'ppt',
					 'Microsoft Excel': 'xls',
					 'Microsoft Word': 'doc',
					 'GPS eXchange Format': 'gpx',
					 'Hancom Hanword': 'hwp',
					 'HTML': 'html',
					 'OpenOffice presentation': 'odp',
					 'OpenOffice spreadsheet': 'ods',
					 'OpenOffice text': 'odt',
					 'Rich Text Format': 'rtf',
					 'Scalable Vector Graphics': 'svg',
					 'TeX/LaTeX': 'tex',
					 'Text': 'txt',
					 'Basic source code': 'bas',
					 'C source code': 'c',
					 'C++ source code': 'cpp',
					 'C# source code': 'cs',
					 'Java source code': 'java',
					 'Perl source code': 'pl',
					 'Python source code': 'py',
					 'Wireless Markup Languag': 'wml'}